@@ -1,12 +1,8 @@
-// Copyright 2013-2015, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
-use gdk_sys;
-use glib;
+use glib::ffi::gconstpointer;
 use glib::translate::*;
-use glib_sys::gconstpointer;
-use gobject_sys;
+use glib::StaticType;
 use std::fmt;
 use std::hash::{Hash, Hasher};
 use std::mem;
@@ -17,6 +13,7 @@ pub struct RgbaParseError;
 
 #[derive(Clone, Copy, Debug)]
 #[repr(C)]
+#[doc(alias = "GdkRGBA")]
 pub struct RGBA {
     pub red: f64,
     pub green: f64,
@@ -79,7 +76,7 @@ impl RGBA {
 impl fmt::Display for RGBA {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let string: glib::GString =
-            unsafe { from_glib_full(gdk_sys::gdk_rgba_to_string(self.to_glib_none().0)) };
+            unsafe { from_glib_full(ffi::gdk_rgba_to_string(self.to_glib_none().0)) };
         f.write_str(&string)
     }
 }
@@ -90,7 +87,7 @@ impl FromStr for RGBA {
         skip_assert_initialized!();
         unsafe {
             let mut rgba = RGBA::uninitialized();
-            if from_glib(gdk_sys::gdk_rgba_parse(
+            if from_glib(ffi::gdk_rgba_parse(
                 rgba.to_glib_none_mut().0,
                 s.to_glib_none().0,
             )) {
@@ -103,16 +100,18 @@ impl FromStr for RGBA {
 }
 
 impl Hash for RGBA {
+    #[doc(alias = "gdk_rgba_hash")]
     fn hash<H: Hasher>(&self, state: &mut H) {
-        let hash = unsafe { gdk_sys::gdk_rgba_hash(self.to_glib_none().0 as gconstpointer) };
+        let hash = unsafe { ffi::gdk_rgba_hash(self.to_glib_none().0 as gconstpointer) };
         state.write_u32(hash);
     }
 }
 
 impl PartialEq for RGBA {
+    #[doc(alias = "gdk_rgba_equal")]
     fn eq(&self, other: &RGBA) -> bool {
         unsafe {
-            from_glib(gdk_sys::gdk_rgba_equal(
+            from_glib(ffi::gdk_rgba_equal(
                 self.to_glib_none().0 as gconstpointer,
                 other.to_glib_none().0 as gconstpointer,
             ))
@@ -126,66 +125,66 @@ impl Eq for RGBA {}
 impl Uninitialized for RGBA {
     #[inline]
     unsafe fn uninitialized() -> Self {
-        mem::uninitialized()
+        mem::zeroed()
     }
 }
 
 #[doc(hidden)]
-impl<'a> ToGlibPtr<'a, *const gdk_sys::GdkRGBA> for RGBA {
+impl<'a> ToGlibPtr<'a, *const ffi::GdkRGBA> for RGBA {
     type Storage = &'a Self;
 
     #[inline]
-    fn to_glib_none(&'a self) -> Stash<'a, *const gdk_sys::GdkRGBA, Self> {
+    fn to_glib_none(&'a self) -> Stash<'a, *const ffi::GdkRGBA, Self> {
         let ptr: *const RGBA = &*self;
-        Stash(ptr as *const gdk_sys::GdkRGBA, self)
+        Stash(ptr as *const ffi::GdkRGBA, self)
     }
 }
 
 #[doc(hidden)]
-impl<'a> ToGlibPtrMut<'a, *mut gdk_sys::GdkRGBA> for RGBA {
+impl<'a> ToGlibPtrMut<'a, *mut ffi::GdkRGBA> for RGBA {
     type Storage = &'a mut Self;
 
     #[inline]
-    fn to_glib_none_mut(&'a mut self) -> StashMut<'a, *mut gdk_sys::GdkRGBA, Self> {
+    fn to_glib_none_mut(&'a mut self) -> StashMut<'a, *mut ffi::GdkRGBA, Self> {
         let ptr: *mut RGBA = &mut *self;
-        StashMut(ptr as *mut gdk_sys::GdkRGBA, self)
+        StashMut(ptr as *mut ffi::GdkRGBA, self)
     }
 }
 
 #[doc(hidden)]
-impl FromGlibPtrNone<*const gdk_sys::GdkRGBA> for RGBA {
-    unsafe fn from_glib_none(ptr: *const gdk_sys::GdkRGBA) -> Self {
+impl FromGlibPtrNone<*const ffi::GdkRGBA> for RGBA {
+    unsafe fn from_glib_none(ptr: *const ffi::GdkRGBA) -> Self {
         *(ptr as *const RGBA)
     }
 }
 
 #[doc(hidden)]
-impl FromGlibPtrNone<*mut gdk_sys::GdkRGBA> for RGBA {
-    unsafe fn from_glib_none(ptr: *mut gdk_sys::GdkRGBA) -> Self {
+impl FromGlibPtrNone<*mut ffi::GdkRGBA> for RGBA {
+    unsafe fn from_glib_none(ptr: *mut ffi::GdkRGBA) -> Self {
         *(ptr as *mut RGBA)
     }
 }
 
 #[doc(hidden)]
-impl FromGlibPtrBorrow<*const gdk_sys::GdkRGBA> for RGBA {
-    unsafe fn from_glib_borrow(ptr: *const gdk_sys::GdkRGBA) -> Self {
-        *(ptr as *const RGBA)
+impl FromGlibPtrBorrow<*const ffi::GdkRGBA> for RGBA {
+    unsafe fn from_glib_borrow(ptr: *const ffi::GdkRGBA) -> glib::translate::Borrowed<Self> {
+        glib::translate::Borrowed::new(*(ptr as *const RGBA))
     }
 }
 
 #[doc(hidden)]
-impl FromGlibPtrBorrow<*mut gdk_sys::GdkRGBA> for RGBA {
-    unsafe fn from_glib_borrow(ptr: *mut gdk_sys::GdkRGBA) -> Self {
-        *(ptr as *mut RGBA)
+impl FromGlibPtrBorrow<*mut ffi::GdkRGBA> for RGBA {
+    unsafe fn from_glib_borrow(ptr: *mut ffi::GdkRGBA) -> glib::translate::Borrowed<Self> {
+        glib::translate::Borrowed::new(*(ptr as *mut RGBA))
     }
 }
 
 #[doc(hidden)]
-impl FromGlibPtrFull<*mut gdk_sys::GdkRGBA> for RGBA {
+impl FromGlibPtrFull<*mut ffi::GdkRGBA> for RGBA {
     #[inline]
-    unsafe fn from_glib_full(ptr: *mut gdk_sys::GdkRGBA) -> Self {
+    unsafe fn from_glib_full(ptr: *mut ffi::GdkRGBA) -> Self {
         let rgba = *(ptr as *mut RGBA);
-        gdk_sys::gdk_rgba_free(ptr);
+        ffi::gdk_rgba_free(ptr);
         rgba
     }
 }
@@ -193,32 +192,54 @@ impl FromGlibPtrFull<*mut gdk_sys::GdkRGBA> for RGBA {
 impl glib::StaticType for RGBA {
     fn static_type() -> glib::types::Type {
         skip_assert_initialized!();
-        unsafe { from_glib(gdk_sys::gdk_rgba_get_type()) }
+        unsafe { from_glib(ffi::gdk_rgba_get_type()) }
     }
 }
 
-impl<'a> glib::value::FromValueOptional<'a> for RGBA {
-    unsafe fn from_value_optional(value: &'a glib::Value) -> Option<Self> {
-        from_glib_full(
-            gobject_sys::g_value_dup_boxed(value.to_glib_none().0) as *mut gdk_sys::GdkRGBA
-        )
+impl glib::value::ValueType for RGBA {
+    type Type = Self;
+}
+
+unsafe impl<'a> glib::value::FromValue<'a> for RGBA {
+    type Checker = glib::value::GenericValueTypeOrNoneChecker<Self>;
+
+    unsafe fn from_value(value: &'a glib::Value) -> Self {
+        skip_assert_initialized!();
+
+        let ptr = glib::gobject_ffi::g_value_get_boxed(value.to_glib_none().0);
+        assert!(!ptr.is_null());
+        from_glib_none(ptr as *mut ffi::GdkRGBA)
     }
 }
 
-impl glib::value::SetValue for RGBA {
-    unsafe fn set_value(value: &mut glib::Value, this: &Self) {
-        gobject_sys::g_value_set_boxed(
-            value.to_glib_none_mut().0,
-            this.to_glib_none().0 as gconstpointer,
-        )
+impl glib::value::ToValue for RGBA {
+    fn to_value(&self) -> glib::Value {
+        unsafe {
+            let mut value = glib::Value::from_type(<RGBA as glib::StaticType>::static_type());
+            glib::gobject_ffi::g_value_set_boxed(
+                value.to_glib_none_mut().0,
+                self.to_glib_none().0 as *mut _,
+            );
+            value
+        }
+    }
+
+    fn value_type(&self) -> glib::Type {
+        RGBA::static_type()
     }
 }
 
-impl glib::value::SetValueOptional for RGBA {
-    unsafe fn set_value_optional(value: &mut glib::Value, this: Option<&Self>) {
-        gobject_sys::g_value_set_boxed(
-            value.to_glib_none_mut().0,
-            this.to_glib_none().0 as gconstpointer,
-        )
+impl glib::value::ToValueOptional for RGBA {
+    fn to_value_optional(s: Option<&Self>) -> glib::Value {
+        skip_assert_initialized!();
+        let mut value = glib::Value::for_value_type::<Self>();
+        unsafe {
+            glib::gobject_ffi::g_value_set_boxed(
+                value.to_glib_none_mut().0,
+                s.to_glib_none().0 as *mut _,
+            );
+        }
+
+        value
     }
 }
